@@ -2,3 +2,7 @@
 #
 # See /LICENCE.md for Copyright information
 """Entry point for tests."""
+
+import os
+
+os.environ["JOBSTAMPS_DISABLED"] = "1"
